@@ -24,7 +24,6 @@
 from .adabound import AdaBound
 from .adahessian import AdaHessian
 from .adan import Adan
-from .autowu import AutoWU
 from .custom import epochwise_onecycle
 from .custom import onecycle_lincos
 from .custom import onecycle_linlin
@@ -42,7 +41,6 @@ del adahessian
 del adan
 del custom
 del lion
-del autowu
 del lookahead
 del lookaround
 del radam
